@@ -121,14 +121,17 @@ yourlabs.Widget.prototype.freeDeck = function() {
 }
 
 // Empty the search input and hide it if maxValues has been reached.
-yourlabs.Widget.prototype.resetDisplay = function() {
+yourlabs.Widget.prototype.resetDisplay = function(initialize) {
     var selected = this.select.find('option:selected').length;
 
     if (this.maxValues && selected == this.maxValues) {
         var index = $(':input:visible').index(this.input);
         this.input.hide();
         var next = $(':input:visible:eq('+ index +')');
-        next.focus()
+
+        if (initialize !== true) {
+            next.focus()
+        }
     } else {
         this.input.show();
     }
@@ -247,9 +250,16 @@ yourlabs.Widget.prototype.initialize = function() {
         this.input.yourlabsAutocomplete().choiceSelector);
 
     this.addRemove(choices);
-    this.resetDisplay();
+    this.resetDisplay(true);
 
     this.bindSelectChoice();
+    this.clearBoth()
+}
+
+// Add an empty div with clear:both after the widget's container.
+// This is meant to support django-responsive-admin templates.
+yourlabs.Widget.prototype.clearBoth = function() {
+    this.widget.parent().append('<div style="clear: both"></div>');
 }
 
 // Destroy the widget. Takes a widget element because a cloned widget element
